@@ -71,10 +71,48 @@ class FactoryMaterialItem(scrapy.Item):
     manner_packing=scrapy.Field() #包装方式
     layout_design=scrapy.Field()  #电路图
     other_pdf_url=scrapy.Field()  #其他规格书{"名称":"pdf链接"}
-    raw_pdf_url = scrapy.Field()
-    raw_img_url = scrapy.Field()
-    raw_other_pdf_url = scrapy.Field()
 
+
+class FactoryMaterialItemMongo(scrapy.Item):
+    table = 'ware_detail' # 测试库bd-crawler 正式库bd-spider
+    def __init__(self, *args, **kwargs):
+        table_params = {'table':kwargs.get('table',self.table)} if not kwargs.get('table_add','') \
+            else {'table':kwargs.get('table',self.table)+kwargs.get('table_add','')}
+        self.__dict__.update(table_params)
+        self._values = {}
+        if args or kwargs and 'table' not in kwargs and 'table_add' not in kwargs:  # avoid creating dict for most common case
+            for k, v in dict(*args, **kwargs).items():
+                self[k] = v
+    sources=scrapy.Field()# 来源：oneyac-唯样，szlcsc-立创，datasheet5
+    url=scrapy.Field()# 详情链接 <----
+    title=scrapy.Field()  #型号  <----
+    img_url=scrapy.Field() #图片链接,如果有多个会以 | 隔开  <----
+    pdf_url=scrapy.Field() #pdf链接,如果有多个会以 | 隔开  <----
+    category_name=scrapy.Field()  #分类名称  <----
+    category_id=scrapy.Field()#xcc分类id  <---- {原厂英文名}_{分类英文名或者拼音(不要留空格)}
+    brand_name=scrapy.Field() # 品牌名称
+    brand_id=scrapy.Field()   #xcc品牌id
+    descs=scrapy.Field()  #描述 <----
+    container_json=scrapy.Field() #头的全部内容 
+    other_url_json=scrapy.Field() #其他链接的json
+    list_json=scrapy.Field()  #列表json <---- 参数数据json单层结构
+    number=scrapy.Field() #总数量 
+    spider_flag=scrapy.Field()#是否爬取当前url: 1是，0否,null否
+    spider_number=scrapy.Field()  #已爬取数量
+    create_time=scrapy.Field()#创建时间 <----
+    creator=scrapy.Field()#创建人 <-----
+    packing=scrapy.Field()#封装，同型号的多个用，号隔开 <----
+    price_json=scrapy.Field() #价格json，格式如：[{"price":"1.2","qty":1}]
+    mpq=scrapy.Field()#最小包装量
+    moq=scrapy.Field()#最小起订量
+    min_work_tp=scrapy.Field()#最低工作温度(单位摄氏度)
+    max_work_tp=scrapy.Field()#最高工作温度(单位摄氏度)
+    rough_weight=scrapy.Field()   #毛重(单位g)
+    manner_packing=scrapy.Field() #包装方式
+    layout_design=scrapy.Field()  #电路图
+    other_pdf_url=scrapy.Field()  #其他规格书{"名称":"pdf链接"}
+
+    
 class FactoryCatergoryItem(scrapy.Item):
     table = 'ware_category' # 测试库bd-crawler 正式库bd-spider
     def __init__(self, *args, **kwargs):
